tempfiles

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2021 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewWorkload

func NewWorkload(config *Config) noisia.Workload

Types

type Config

type Config struct {
	// PostgresConninfo defines connections string used for connecting to Postgres.
	PostgresConninfo string
	// Jobs defines how many workers should be created for producing temp files.
	Jobs uint16
	// TempFilesRate defines rate interval for queries executing.
	TempFilesRate int
	// TempFilesScaleFactor defines multiplier for amount of fixtures in temporary table.
	TempFilesScaleFactor int
}

Config defines configuration settings for temp files workload

Jump to